pycosat: SAT solver picosat with Python bindings
================================================

Description
-----------

PicoSAT is a popular SAT solver written by Armin Biere in pure C. This
package provides efficient Python bindings to picosat on the C level,
i.e. when importing pycosat, the picosat solver becomes part of the
Python process itself. For ease of deployment, the picosat source
(namely picosat.c and picosat.h) is included in this project. These
files have been extracted from the picosat source.

License
-------

MIT


Upstream Contact
----------------

- PicoSAT: http://fmv.jku.at/picosat/
- pycosat: https://github.com/ContinuumIO/pycosat

Special Update/Build Instructions
---------------------------------

None.
